#
# spec file for package perl-Log-Dispatchouli
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Log-Dispatchouli
Name:           perl-Log-Dispatchouli
Version:        3.9.0
Release:        1.1
# 3.009 -> normalize -> 3.9.0
%define cpan_version 3.009
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Simple wrapper around Log::Dispatch
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/R/RJ/RJBS/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.78
BuildRequires:  perl(JSON::MaybeXS)
BuildRequires:  perl(Log::Dispatch)
BuildRequires:  perl(Log::Dispatch::Array)
BuildRequires:  perl(Log::Dispatch::File)
BuildRequires:  perl(Log::Dispatch::Screen)
BuildRequires:  perl(Log::Dispatch::Syslog)
BuildRequires:  perl(Params::Util)
BuildRequires:  perl(String::Flogger)
BuildRequires:  perl(Sub::Exporter)
BuildRequires:  perl(Sub::Exporter::GlobExporter) >= 0.002
BuildRequires:  perl(Sys::Syslog) >= 0.16
BuildRequires:  perl(Test::Deep)
BuildRequires:  perl(Test::Fatal)
BuildRequires:  perl(Test::More) >= 0.96
BuildRequires:  perl(Try::Tiny) >= 0.04
BuildRequires:  perl(experimental)
Requires:       perl(Log::Dispatch)
Requires:       perl(Log::Dispatch::Array)
Requires:       perl(Log::Dispatch::File)
Requires:       perl(Log::Dispatch::Screen)
Requires:       perl(Log::Dispatch::Syslog)
Requires:       perl(Params::Util)
Requires:       perl(String::Flogger)
Requires:       perl(Sub::Exporter)
Requires:       perl(Sub::Exporter::GlobExporter) >= 0.002
Requires:       perl(Sys::Syslog) >= 0.16
Requires:       perl(Try::Tiny) >= 0.04
Requires:       perl(experimental)
Provides:       perl(Log::Dispatchouli) = %{version}
Provides:       perl(Log::Dispatchouli::Global) = %{version}
Provides:       perl(Log::Dispatchouli::Proxy) = %{version}
Provides:       perl(Log::Fmt) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
Log::Dispatchouli is a thin layer above Log::Dispatch and meant to make it
dead simple to add logging to a program without having to think much about
categories, facilities, levels, or things like that. It is meant to make
logging just configurable enough that you can find the logs you want and
just easy enough that you will actually log things.

Log::Dispatchouli can log to syslog (if you specify a facility), standard
error or standard output, to a file, or to an array in memory. That last
one is mostly useful for testing.

In addition to providing as simple a way to get a handle for logging
operations, Log::Dispatchouli uses String::Flogger to process the things to
be logged, meaning you can easily log data structures. Basically: strings
are logged as is, arrayrefs are taken as (sprintf format, args), and
subroutines are called only if needed. For more information read the
String::Flogger docs.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Wed Jan  8 2025 Tina Müller <timueller+perl@suse.de>
- updated to 3.9.0 (3.009)
  see /usr/share/doc/packages/perl-Log-Dispatchouli/Changes
  3.009     2025-01-07 21:22:25-05:00 America/New_York
  - added documentation of the enable_stdout and enable_stderr methods,
    added in 2.018
  3.008     2024-11-02 16:59:01+00:00 Europe/London
  - log_pid can now be a comma-delimited list of outputs, which is most
    likely useful for setting log_pid to "syslog" only
  - mark "to_file" for removal, probably in Nov 2025
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Tue Sep  5 2023 Tina Müller <timueller+perl@suse.de>
- updated to 3.007
  see /usr/share/doc/packages/perl-Log-Dispatchouli/Changes
  3.007     2023-09-02 20:18:04-04:00 America/New_York
  - add the is_X methods to Proxy as they were on the root logger
    (thanks, Charlie Garrison)
  - in Log::Fmt tests, cope with the slightly different output of
    JSON::PP versus the XS implementations
  3.006     2023-08-11 10:58:09-04:00 America/New_York
  - fix a bug in Log::Fmt where an event data value that was a reference
    to a reference to an array was logged as its 0th element, not a
    flogged array reference
* Fri Jun  9 2023 Tina Müller <timueller+perl@suse.de>
- updated to 3.005
  see /usr/share/doc/packages/perl-Log-Dispatchouli/Changes
  3.005     2023-06-08 20:41:02-04:00 America/New_York
  - add parse_event_string_as_hash, which loses duplicate k/v pairs
    but makes life a little easier
  3.004     2023-06-05 21:26:03-04:00 America/New_York
  - optimization to parsing of quoted strings (thanks, Rob Mueller)
  3.003     2023-06-05 08:10:52-04:00 America/New_York
  - Log::Fmt will now flog ref-refs, meaning you can easily log JSON as
    log event values
* Wed Dec  7 2022 Tina Müller <timueller+perl@suse.de>
- updated to 3.002
  see /usr/share/doc/packages/perl-Log-Dispatchouli/Changes
  3.002     2022-12-06 09:49:34-05:00 America/New_York
  - restore v5.20 compatibility by turning on "postderef" feature
    explicitly
  3.001     2022-12-01 11:55:43-05:00 America/New_York
  - no changes, just stable
  3.000     2022-11-03 21:29:21-04:00 America/New_York (TRIAL RELEASE)
  - Log::Dispatchouli now requires v5.20, for pair slices
  - structured event logging with ->log_event -- read the docs, and Log::Fmt
* Sat Jun 19 2021 Tina Müller <timueller+perl@suse.de>
- updated to 2.023
  see /usr/share/doc/packages/perl-Log-Dispatchouli/Changes
  2.023     2021-06-18 21:52:17-04:00 America/New_York
  - update author contact info
  - add perl-support section
* Tue Aug 25 2020 Tina Müller <timueller+perl@suse.de>
- updated to 2.022
  see /usr/share/doc/packages/perl-Log-Dispatchouli/Changes
  2.022     2020-08-24 13:50:15-04:00 America/New_York
  - don't duplicate pid in syslog!
* Thu Aug 13 2020 Tina Müller <timueller+perl@suse.de>
- updated to 2.021
  see /usr/share/doc/packages/perl-Log-Dispatchouli/Changes
  2.021     2020-08-12 11:48:57-04:00 America/New_York
  - add another experimental means to replace how Syslog output is set up
  2.020     2020-02-06 13:45:44-05:00 America/New_York (TRIAL RELEASE)
  - add stdio_dispatcher_class, so you can subclass the Screen dispatcher
    for stderr and stdio; this is experimental!
* Tue Jul 30 2019 Stephan Kulow <coolo@suse.com>
- updated to 2.019
  see /usr/share/doc/packages/perl-Log-Dispatchouli/Changes
  2.019     2019-07-27 16:13:30-04:00 America/New_York
  - fix an initialization ordering bug for loggers using stdio
* Sat Jul 27 2019 Stephan Kulow <coolo@suse.com>
- updated to 2.018
  see /usr/share/doc/packages/perl-Log-Dispatchouli/Changes
  2.018     2019-07-26 18:36:56-04:00 America/New_York
  - add enable_stdout and enable_stderr to, uh, enable stdout and enable
    stderr (after initial construction)
* Wed Mar 13 2019 Stephan Kulow <coolo@suse.com>
- updated to 2.017
  see /usr/share/doc/packages/perl-Log-Dispatchouli/Changes
  2.017     2019-03-12 21:10:26-04:00 America/New_York
  - syslog_socket can now be supplied to replace the native socket for
    Sys::Syslog (thanks, Jon Stuart!)
* Thu Feb 22 2018 coolo@suse.com
- updated to 2.016
  see /usr/share/doc/packages/perl-Log-Dispatchouli/Changes
  2.016     2018-02-21 12:47:46-05:00 America/New_York
  - the Proxy logger now respects the same overloading as the root logger
  - muted works as a constructor argument (thanks, Dan Book)
* Tue Oct 18 2016 coolo@suse.com
- updated to 2.015
  see /usr/share/doc/packages/perl-Log-Dispatchouli/Changes
  2.015     2016-10-17 15:42:54-04:00 America/New_York
  - Log::Dispatchouli subclass can now provide its own proxy_class
    method to use something other than Log::Dispatchouli::Proxy
* Sun Oct 16 2016 coolo@suse.com
- updated to 2.014
  see /usr/share/doc/packages/perl-Log-Dispatchouli/Changes
  2.014     2016-10-14 18:28:36-04:00 America/New_York
  - non-trial release of v2.013
  2.013     2016-07-30 16:34:57-04:00 America/New_York (TRIAL RELEASE)
  - minor optimizations to callbacks (thanks, Olivier Mengué)
* Tue Apr 14 2015 coolo@suse.com
- updated to 2.012
  see /usr/share/doc/packages/perl-Log-Dispatchouli/Changes
  2.012     2014-11-30 08:49:01-05:00 America/New_York
    avoid a newly-introduced warning on older perls (thanks, Christopher
    J. Madsen)
  2.011     2014-11-29 08:50:45-05:00 America/New_York
    some optimizations in timestamp and pid logging (thanks, Olivier
    Mengué)
* Mon Sep 15 2014 coolo@suse.com
- updated to 2.010
  add the file_format option (thanks, Randy Stauner)
* Mon Feb 24 2014 coolo@suse.com
- updated to 2.009
  load the Proxy class earlier, to get it loaded prefork
* Fri Oct  4 2013 coolo@suse.com
- updated to 2.008
    fix test for JSON::PP, which doesn't always follow orders about
    spaces!  (thanks, Dagfinn Ilmari Mannsåker!)
    doc fixes and tests (thanks George Hartzell and Randy Stauner)
* Wed Jun  5 2013 coolo@suse.com
- updated to 2.006
    put the ->info, ->fatal, ->debug methods on proxies, too
    (thanks George Hartzell)
* Sat Apr 30 2011 coolo@opensuse.org
- updated to 2.005
    add log_file and log_path options
    BUG FIX:  it is okay to replace the default logger, always
    add config_id to allow faking Global equality when testing
* Mon Jan 17 2011 coolo@novell.com
- initial package 2.002
  * created by cpanspec 1.78.03
